@@ -6,20 +6,24 @@ hrnet_v2p_w18 = [
     (64, 4, ConvLayer(3)),
     [
         [(64, 4)] * 4,
-    ] * 1,
+    ]
+    * 1,
     ((18, 4), (36, 8)),
     [
         [((18, 4), (36, 8))] * 4,
         ((18, 4), (36, 8)),
-    ] * 1,
+    ]
+    * 1,
     ((18, 4), (36, 8), (72, 16)),
     [
         [((18, 4), (36, 8), (72, 16))] * 4,
         ((18, 4), (36, 8), (72, 16)),
-    ] * 4,
+    ]
+    * 4,
     ((18, 4), (36, 8), (72, 16), (144, 32)),
     [
         [((18, 4), (36, 8), (72, 16), (144, 32))] * 4,
         ((18, 4), (36, 8), (72, 16), (144, 32)),
-    ] * 3,
+    ]
+    * 3,
 ]
